등록특허 10-0680003

분자내이중N-알킬화반응에의한피페리딘고리의최종고리화반응에기초한3-2-[4-(6-플로로벤조(D)아이소옥사졸 -3-일)-피페리딘-1-일]-에틸-2-메틸-6,7,8,9-테트라하이드로-4H-피리도-(1,2-a)피리미딘-4-온(I)의 제조를 위한 방법을개시하고있다(도식2).

Illustration

중간체VIII의 제조에 사용되는 출발 물질들 중에 하나는 상업적으로 입수할 수 없는 4-테트라하이드로피란카보닐클로라 이드(IX)이다. 게다가, IX로부터 VIII을 제조하는 것은 다섯 단계로 이루어진다(스페인특허 제2074966호).

Illustration

본발명은3-2-[4-(6-플로로벤조(D)아이소옥사졸-3-일)-피페리딘-1-일]-에틸-2-메틸-6,7,8,9-테트라하이드로- 4H-피리도-(1,2-a)피리미딘-4-온(I)의 제조를 위한 대체적 방법을 제공하며, 그 과정이 도식 3에 도해되어있다.

- 6 -